==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24AttributeTracker.h <==
// class javax.swing.text.StyledEditorKit$AttributeTracker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 54eae1576e8125ca javax_swing_text_StyledEditorKit__24AttributeTracker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_
#define _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_CaretEvent$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_StyledEditorKit$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$_init$c33cd79206f69200(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_text_StyledEditorKit$object *);

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$caretUpdate$12cb79761daa9fdb(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_event_CaretEvent$object *);
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$updateInputAttributes$63550799210dfc13(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, jint, jint, struct _jc_javax_swing_text_JTextComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$caretUpdate$12cb79761daa9fdb;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$propertyChange$6d3500eaa79bf44b;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$updateInputAttributes$63550799210dfc13;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods {
	void	(*caretUpdate$12cb79761daa9fdb)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_event_CaretEvent$object *);
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
	void	(*updateInputAttributes$63550799210dfc13)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, jint, jint, struct _jc_javax_swing_text_JTextComponent$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods	javax_swing_text_StyledEditorKit__24AttributeTracker;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs {
	struct _jc_javax_swing_text_StyledEditorKit$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs {
    _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs	javax_swing_text_StyledEditorKit__24AttributeTracker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs	javax_swing_text_StyledEditorKit__24AttributeTracker;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object {
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24AttributeTracker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyledEditorKit__24AttributeTracker.h <==
// class javax.swing.text.StyledEditorKit$AttributeTracker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 54eae1576e8125ca javax_swing_text_StyledEditorKit__24AttributeTracker

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_
#define _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_CaretEvent$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_StyledEditorKit$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$_init$c33cd79206f69200(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_text_StyledEditorKit$object *, struct _jc_javax_swing_text_StyledEditorKit$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$caretUpdate$12cb79761daa9fdb(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method$updateInputAttributes$63550799210dfc13(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, jint, jint, struct _jc_javax_swing_text_JTextComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$caretUpdate$12cb79761daa9fdb;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$propertyChange$6d3500eaa79bf44b;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$method_info$updateInputAttributes$63550799210dfc13;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods {
	void	(*caretUpdate$12cb79761daa9fdb)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_javax_swing_event_CaretEvent$object *) _JC_JCNI_ATTR;
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	void	(*updateInputAttributes$63550799210dfc13)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object *, jint, jint, struct _jc_javax_swing_text_JTextComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vmethods	javax_swing_text_StyledEditorKit__24AttributeTracker;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs {
	struct _jc_javax_swing_text_StyledEditorKit$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs {
    _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_refs	javax_swing_text_StyledEditorKit__24AttributeTracker;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$sub_nonrefs	javax_swing_text_StyledEditorKit__24AttributeTracker;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$object {
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24AttributeTracker$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$vtype _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24AttributeTracker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24AttributeTracker$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24AttributeTracker_H_ */
